// config.h

// This configuration file should reside in the same Arduino
// directory as the weather station file D1M-WX1_IoT-APRS.ino.

// *******************************************************
// **************** STATION FACTORS **********************
// *******************************************************

// If you have performed the voltage calibration steps, enter
// the voltage you measured on your digital multimeter and
// the voltage reported by the ADC on the serial monitor.
// If you have not performed the calibration, do not change 
// the default values. They should be equal.

const float dmmVoltage = 4.45;
const float adcVoltage = 4.45;

// station altitude in meters
// https://www.freemaptools.com/elevation-finder.htm
const float STATION_ELEV = 90.0;

// update interval in seconds
// must be longer than 15 seconds
// suggest 300 seconds for testing, 600 or 900 for use
const long SLEEP_INTERVAL = 600;

// *******************************************************
// ********************* WIFI LOGON **********************
// *******************************************************

// ENTER YOUR SSID
const char ssid[] = "yourWiFi_SSID";

// ENTER YOUR PASSWORD
const char password[] = "yourWiFi_PW";

// *******************************************************
// ******************** THINGSPEAK ***********************
// *******************************************************

// ThingSpeak Channel ID
String ChannelID = "yourChannelID";

// API write key for your ThingSpeak channel
String apiWriteKey = "yourAPI_write_Key";

// ThingSpeak Server - do not change
const char IOT_SERVER[] = "api.thingspeak.com";

// *******************************************************
// ******************** APRS-IS **************************
// *******************************************************

// station location in APRS format
// NOTE: latitude must have 4 digits left of the decimal. Pad with 0s.
//       longitude must have 5 digits left of the decimal. Pad with 0s.
// Find your location at aprs.fi using "Address, city or locator" box
const char APRSlocation[] = "ddmm.hhN/dddmm.hhWW";

// select an APRS-IS Tier 2 server close to your station
// or use the default
// for list of servers: http://www.aprs2.net/serverstats.php
const char APRS_SERVER[] = "iad.aprs2.net";
const int APRS_PORT = 14580;   // do not change

// define your callsign and passcode
// use SSID -13 for weather stations
// see http://www.aprs.org/aprs11/SSIDs.txt
const String APRScallsign = "callsign-ssid";

// for passcode www.george-smart.co.uk/aprs/aprs_callpass/
// or http://n5dux.com/ham/aprs-passcode/
const char APRSpasscode[] = "nnnn";
